Exception: ActiveRecord::Tenanted::WrongTenantError

Inherits:
Error
  • Object
show all
Defined in:
lib/active_record/tenanted.rb

Overview

Raised when database access is attempted on a record whose tenant does not match the current tenant.